==> zio-aws-macie2_3-5.17.116.1-sources.jar: zio/aws/macie2/model/CriteriaBlockForJob.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CriteriaBlockForJob(
    and: Option[Iterable[zio.aws.macie2.model.CriteriaForJob]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob = {
    import CriteriaBlockForJob.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob
      .builder()
      .optionallyWith(
        and.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.and)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.CriteriaBlockForJob.ReadOnly =
    zio.aws.macie2.model.CriteriaBlockForJob.wrap(buildAwsValue())
}
object CriteriaBlockForJob {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.CriteriaBlockForJob =
      zio.aws.macie2.model.CriteriaBlockForJob(
        and.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def and: Option[List[zio.aws.macie2.model.CriteriaForJob.ReadOnly]]
    def getAnd: ZIO[Any, AwsError, List[
      zio.aws.macie2.model.CriteriaForJob.ReadOnly
    ]] = AwsError.unwrapOptionField("and", and)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob
  ) extends zio.aws.macie2.model.CriteriaBlockForJob.ReadOnly {
    override val and
        : Option[List[zio.aws.macie2.model.CriteriaForJob.ReadOnly]] = scala
      .Option(impl.and())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.macie2.model.CriteriaForJob.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob
  ): zio.aws.macie2.model.CriteriaBlockForJob.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_3-7.21.15.5-sources.jar: zio/aws/macie2/model/CriteriaBlockForJob.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CriteriaBlockForJob(
    and: Optional[Iterable[zio.aws.macie2.model.CriteriaForJob]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob = {
    import CriteriaBlockForJob.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob
      .builder()
      .optionallyWith(
        and.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.and)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.CriteriaBlockForJob.ReadOnly =
    zio.aws.macie2.model.CriteriaBlockForJob.wrap(buildAwsValue())
}
object CriteriaBlockForJob {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.CriteriaBlockForJob =
      zio.aws.macie2.model.CriteriaBlockForJob(
        and.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def and: Optional[List[zio.aws.macie2.model.CriteriaForJob.ReadOnly]]
    def getAnd: ZIO[Any, AwsError, List[
      zio.aws.macie2.model.CriteriaForJob.ReadOnly
    ]] = AwsError.unwrapOptionField("and", and)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob
  ) extends zio.aws.macie2.model.CriteriaBlockForJob.ReadOnly {
    override val and
        : Optional[List[zio.aws.macie2.model.CriteriaForJob.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.and())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.macie2.model.CriteriaForJob.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.CriteriaBlockForJob
  ): zio.aws.macie2.model.CriteriaBlockForJob.ReadOnly = new Wrapper(impl)
}
